@@ -14,7 +14,7 @@ cfg = { "pipeline": [   {"type":"dummyStart"},
         "pipeline_settings":{   "print_cfg":1, 
                                 "print_task_result":1, 
                                 "exchange_media":"kafka",
-                                "bootstrap_servers":["192.168.176.1:9092"]}}
+                                "bootstrap_servers":["172.31.0.1:9092"]}}
 
 
 
@@ -31,13 +31,13 @@ task_id = b"3.generateDataFrame"
 df = pipe.kafka_media.read_kafka(task_id=task_id)
 print(df)
 
-# delete the topic
-pipe.kafka_media.delete_topic()
+# # delete the topic
+# pipe.kafka_media.delete_topic()
 
 
 
-pipe = pipe.build_digraph()
-pipe.save_png("./sample11.png")
+# pipe = pipe.build_digraph()
+# pipe.save_png("./sample11.png")
 
 
 # python cetl/dev_tests/sample11_adding_kafka_media.py
\ No newline at end of file
