@@ -3,13 +3,14 @@ sys.path.append('.')
 from cetl import DataPipeline
 
 cfg = {"pipeline":[ {"type":"dummyStart", "module_type":"functional"},
-                    {"breakpoint":"true", "type":"parallelTransformer", "transformers":[
+                    {"type":"parallelTransformer", "transformers":[
+                        {"breakpoint":1, "type":"generateDataFrame"},
                         {"type":"generateDataFrame"},
                         {"type":"generateDataFrame"}
                     ]},
                     {"type":"unionAll"}],
                     
-        "pipeline_settings":{"print_cfg":0, "print_task_result":0}}
+        "pipeline_settings":{"print_cfg":1, "print_task_result":1}}
 
 pipe = DataPipeline(cfg)
 df = pipe.transform("")
