@@ -21,12 +21,13 @@ steps = [   dummyStart(),
             unionAll()]
 
 pipe = build_pipeline(*steps)
+pipe.print_task_result = 1
 df = pipe.transform("")
-# print(df)
+print(df)
 
 
-pipe = pipe.build_digraph()
-pipe.save_png("./sample8.png")
+# pipe = pipe.build_digraph()
+# pipe.save_png("./sample8.png")
 
 
-# python3.6 cetl/dev_tests/sample8_build_pipeline.py
\ No newline at end of file
+# python cetl/dev_tests/sample8_build_pipeline.py
\ No newline at end of file
