@@ -72,7 +72,7 @@ def build_transformer_from_cfg(cfg, registry, parallel_transformers=None):
     transformer_type = args.pop("type")
     
     if transformer_type not in registry.module_dict:
-        print(registry)
+        print("current registry is ", registry._name)
         raise ValueError(f"transformer_type {transformer_type} not exists")
 
     cls_obj = registry.module_dict[transformer_type]
