@@ -110,7 +110,7 @@ def recursive_build_pipeline_from_cfg(  cfg,
                                                                 trans_cfg["transformers"]):
  
                 if "type" in sub_trans_cfg:
-                    sub_trans_name = sub_trans_cfg.get("type")
+                    sub_trans_name = sub_trans_cfg.get("type") #get the transformer type
                     ############################### dealling with previous transformer is also parallelTransformer
                     assert sub_trans_name!="parallelTransformer", "parallel is not acceptable in parallelTransfomer"
                     ######################### END
@@ -119,8 +119,8 @@ def recursive_build_pipeline_from_cfg(  cfg,
                     index = index + 1
                     sub_breakpoint = sub_trans_cfg.pop("breakpoint") if "breakpoint" in sub_trans_cfg else 0
                     description = sub_trans_cfg.pop("description") if "description" in sub_trans_cfg else ""
-                    module_type = trans_cfg.pop("module_type") if "module_type" in sub_trans_cfg else ""
-                    TRANSFORMERS = get_register(module_type)
+                    module_type = sub_trans_cfg.pop("module_type") if "module_type" in sub_trans_cfg else ""
+                    TRANSFORMERS = get_register(module_type, pipeline_settings.default_type)
                     # print(TRANSFORMERS)
                     transformer = build_transformer_from_cfg(sub_trans_cfg, TRANSFORMERS)
                     transformer.pre_node_name = node_name
@@ -215,7 +215,7 @@ def recursive_build_pipeline_from_cfg(  cfg,
             # breakpoint=trans_cfg.pop("breakpoint") if "breakpoint" in trans_cfg else 0
             description = trans_cfg.pop("description") if "description" in trans_cfg else ""
             module_type = trans_cfg.pop("module_type") if "module_type" in trans_cfg else ""
-            TRANSFORMERS = get_register(module_type)
+            TRANSFORMERS = get_register(module_type, pipeline_settings.default_type)
             transformer = build_transformer_from_cfg(trans_cfg, TRANSFORMERS)
             transformer.index = index
             transformer.node_name = node_name
@@ -367,7 +367,8 @@ class pipeline_settings():
         self.exchange_media = self.pipeline_settings["exchange_media"] if "exchange_media" in self.pipeline_settings else "default"
         self.delete_kafka_topic = self.pipeline_settings["delete_kafka_topic"] if "delete_kafka_topic" in self.pipeline_settings else 1
         self.bootstrap_servers = self.pipeline_settings["bootstrap_servers"] if "bootstrap_servers" in self.pipeline_settings else []
-        self.default_type = self.pipeline_settings["module_type"] if "default_type" in self.pipeline_settings else ""
+        self.default_type = self.pipeline_settings["module_type"] if "module_type" in self.pipeline_settings else ""
+        print(f"The default module type for this pipeline is set as {self.default_type}")
     
     def get_pipeline_settings_from_cfg(self):
         
