@@ -87,11 +87,12 @@ def transform_wrapper(func):
                         # ---------------------------------------------------------- read message
                         kafka2python = kafka_media.read_kafka(task_id=pre_transformer_key.encode('utf-8'))
                         pre_module_output.append(kafka2python)
-                    
-                else:
+
+                elif isinstance(input, str):
                     # print("pre_transformer_key", pre_transformer_key)
-                    pre_transformer_key = input["key"]
-                    pre_module_output = kafka_media.read_kafka(   task_id=pre_transformer_key.encode('utf-8'))
+                    # there is the in airflow, task relationship is not upstream
+                    pre_transformer_key = input
+                    pre_module_output = ""
                     
             else:
                 pre_module_output = ""
